pub struct FakeJetstream { /* private fields */ }Expand description
A fake Jetstream that can emit synthetic events for testing.
Events are sent through a channel and can be consumed by the application’s event handler.
Implementations
Sourceimpl FakeJetstream
impl FakeJetstream
Sourcepub fn take_receiver(&mut self) -> Option<Receiver<Value>>
pub fn take_receiver(&mut self) -> Option<Receiver<Value>>
Take the receiver (for wiring into the consumer).
Sourcepub async fn emit_post(&self, did: &str, rkey: &str, text: &str) -> Result<()>
pub async fn emit_post(&self, did: &str, rkey: &str, text: &str) -> Result<()>
Emit a synthetic post commit event.